@@ -6,7 +6,7 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -31,7 +31,7 @@
 #define HAVE_KSANE 1
 
 /* Define to 1 if an external Marble shared library have been found */
-#define HAVE_MARBLE 1
+#define HAVE_GEOLOCATION 1
 
 /* Define to 1 if an external Eigen3 shared library have been found */
 #define HAVE_EIGEN3 1
@@ -100,13 +100,13 @@
 #define HAVE_APPSTYLE_SUPPORT 1
 
 /* Define to 1 if system use QtMultimedia */
-/* #undef HAVE_QTMULTIMEDIA */
+#define HAVE_QTMULTIMEDIA 1
 
 /* Define to 1 if system use QtWebEngine */
 #define HAVE_QWEBENGINE 1
 
 /* Define to 1 if system use QtXmlPatterns */
-#define HAVE_QTXMLPATTERNS 1
+/* #undef HAVE_QTXMLPATTERNS */
 
 /* Define to 1 if ImageMagick codecs are supported */
 #define HAVE_IMAGE_MAGICK 1
@@ -114,6 +114,6 @@
 /* Defines to 1 if the Dr. Mingw crash handler should be used */
 /* #undef HAVE_DRMINGW */
 
-#define LIBEXEC_INSTALL_DIR "/usr/lib/libexec"
+#define LIBEXEC_INSTALL_DIR "/usr/libexec"
 
 #endif // DIGIKAM_CONFIG_H
