@@ -7,7 +7,7 @@
  * Description : global macros, variables and flags
  *
  * SPDX-FileCopyrightText: 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -247,11 +247,6 @@ DIGIKAM_EXPORT void installQtTranslationFiles(QApplication& app);
  */
 DIGIKAM_EXPORT QDateTime startOfDay(const QDate&);
 
-/**
- * For bundles only, find or set KSycoca database file in the cache directory.
- */
-DIGIKAM_EXPORT void setupKSycocaDatabaseFile();
-
 /**
  * Open online handbook at the section/chapter/reference page.
  *
