@@ -6,17 +6,9 @@
  * Date        : 2014-09-12
  * Description : Web Service tool utils methods
  *
- * Copyright (C) 2014-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -43,6 +35,8 @@ public:
     explicit WSToolUtils() {};
     ~WSToolUtils()         {};
 
+    static QString decodeKey(const QString& key);
+
     /**
      * Generates random string.
      */
@@ -52,6 +46,17 @@ public:
     static void removeTemporaryDir(const char* prefix);
 
     static QSettings* getOauthSettings(QObject* const parent);
+
+    static void saveToken(const QString& name, const QString& token);
+
+    static QString readToken(const QString& name);
+
+    static void clearToken(const QString& name);
+
+private:
+
+    static QString oauthConfigFile();
+    static QString possibleCharacters();
 };
 
 } // namespace Digikam
